@@ -501,14 +501,14 @@ main (int argc, char *argv[])
 	poptContext pctx;
 	char **args;
 	
-#ifdef ENABLE_NLS
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
-#endif
 
-	procman = gnome_program_init ("procman", VERSION, LIBGNOMEUI_MODULE, argc, argv, 
-			    	      GNOME_PARAM_POPT_TABLE, options, NULL);
+	procman = gnome_program_init ("gnome-system-monitor", VERSION, 
+				      LIBGNOMEUI_MODULE, argc, argv, 
+			    	      GNOME_PARAM_POPT_TABLE, options, 
+				      GNOME_PARAM_APP_DATADIR,DATADIR, NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/procman.png");
 		    
 	gconf_init (argc, argv, NULL);
